@@ -16,7 +16,7 @@ class CustomFieldEditorWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit CustomFieldEditorWidgetTest(QObject *parent = nullptr);
-    ~CustomFieldEditorWidgetTest();
+    ~CustomFieldEditorWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldEnableAddButtonWhenTextIsNotEmpty();
